PopoverActionModel class

Constructors

PopoverActionModel({required String label, required String value, bool isSelected = false, bool isDisabled = false, Widget? icon})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Widget?
getter/setter pair
isDisabled ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
label ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

selectAction(List<PopoverActionModel> filters, String selectedLabel) → void