FormUiHelper class

Constructors

FormUiHelper({double verticalPadding = 20, double horizontalPadding = 16, double inputVerticalSeparator = 20, double sectionSeparator = 20, double suffixPadding = 12, double sectionBorderRadius = 18})

Properties

hashCode → int
The hash code for this object.
no setterinherited
horizontalPadding → double
final
inputVerticalSeparator → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionBorderRadius → double
final
sectionSeparator → double
final
suffixPadding → double
final
verticalPadding → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited