UFUSingleSelectModel class

Constructors

UFUSingleSelectModel({required String label, required String id, Widget? child, Color? color, Color? borderColor, double? borderWidth, Widget? suffix, VoidCallback? onTapItem, dynamic additionalData, String? prefixLabel, String subLabel = '', UFUInputBoxController? labelController, bool? isEditable = false, bool? active = true})
UFUSingleSelectModel.clone(UFUSingleSelectModel source)
factory

Properties

active ↔ bool?
getter/setter pair
additionalData ↔ dynamic
getter/setter pair
borderColor ↔ Color?
getter/setter pair
borderWidth ↔ double?
getter/setter pair
child ↔ Widget?
getter/setter pair
color ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isEditable ↔ bool?
getter/setter pair
label ↔ String
getter/setter pair
labelController ↔ UFUInputBoxController?
getter/setter pair
onTapItem ↔ VoidCallback?
getter/setter pair
prefixLabel ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subLabel ↔ String
getter/setter pair
suffix ↔ Widget?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited