EncryptionUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hexStringToByteArray(
String hex) → Uint8List -
secKeyDecryptedWithSek(
Map< String, dynamic> hashMap) → String? -
secKeyEncryptWithBodyAppKey(
Map< String, dynamic> mParams) → Map<String, dynamic> ? -
secKeyEncryptWithHeaderAppKey(
String auth, Map< String, dynamic> ? jsonDecode) → Map<String, String> ?
Constants
- accountType → const String
- dataKey → const String
- deviceTypeKey → const String
- hash → const String
- sek → const String