Retry class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
cancel()
→ void
-
Cancels the currently scheduled retry (if any)
-
execute(Function? callBack, {Duration? delay})
→ void
-
Executes a function with cooldown and optional delay.
Cancels any previous scheduled retry if not yet executed.